In group chat must has line bot notify included.

Code example.

<div>from django_line_notification.line_notify import LINE</div>
<div>token = 'oiojweifIedDN0209%dp9icdfgergIJiw672gcu7wiu'</div>
<div>line = Line(token)</div>
<div>line.send_msg('foobar')</div>
